@@ -25,6 +25,8 @@
 
 #include <gtk/gtk.h>
 
+#include <dh-book-manager.h>
+
 G_BEGIN_DECLS
 
 typedef struct _DhBase      DhBase;
@@ -45,16 +47,15 @@ struct _DhBaseClass {
         GObjectClass parent_class;
 };
 
-GType        dh_base_get_type                        (void) G_GNUC_CONST;
-DhBase *     dh_base_get                             (void);
-DhBase *     dh_base_new                             (void);
-GtkWidget *  dh_base_new_window                      (DhBase *base);
-GtkWidget *  dh_base_new_assistant                   (DhBase *base);
-GtkWidget *  dh_base_get_window                      (DhBase *base);
-GtkWidget *  dh_base_get_window_on_current_workspace (DhBase *base);
-GNode *      dh_base_get_book_tree                   (DhBase *base);
-GList *      dh_base_get_keywords                    (DhBase *base);
-void         dh_base_quit                            (DhBase *base);
+GType          dh_base_get_type                        (void) G_GNUC_CONST;
+DhBase *       dh_base_get                             (void);
+DhBase *       dh_base_new                             (void);
+GtkWidget *    dh_base_new_window                      (DhBase *base);
+GtkWidget *    dh_base_new_assistant                   (DhBase *base);
+GtkWidget *    dh_base_get_window                      (DhBase *base);
+GtkWidget *    dh_base_get_window_on_current_workspace (DhBase *base);
+DhBookManager *dh_base_get_book_manager                (DhBase *base);
+void           dh_base_quit                            (DhBase *base);
 
 G_END_DECLS
 
