@@ -465,25 +465,25 @@ dh_util_state_manage_paned (GtkPaned    *paned,
 }
 
 GSList *
-dh_util_state_load_books_disabled (void)
+dh_util_state_load_disabled_books (void)
 {
         gchar *key;
-        GSList *books_disabled = NULL;
+        GSList *disabled_books = NULL;
 
-        key = util_state_get_key ("main/contents", "books_disabled");
-        ige_conf_get_string_list (ige_conf_get (), key, &books_disabled);
+        key = util_state_get_key ("main/contents", "disabled_books");
+        ige_conf_get_string_list (ige_conf_get (), key, &disabled_books);
         g_free(key);
 
-        return books_disabled;
+        return disabled_books;
 }
 
 void
-dh_util_state_store_books_disabled (GSList *books_disabled)
+dh_util_state_store_disabled_books (GSList *disabled_books)
 {
         gchar *key;
 
-        key = util_state_get_key ("main/contents", "books_disabled");
-        ige_conf_set_string_list (ige_conf_get (), key, books_disabled);
+        key = util_state_get_key ("main/contents", "disabled_books");
+        ige_conf_set_string_list (ige_conf_get (), key, disabled_books);
         g_free(key);
 }
 
@@ -517,7 +517,7 @@ util_state_notebook_timeout_cb (gpointer notebook)
 
 static void
 util_state_notebook_switch_page_cb (GtkWidget       *notebook,
-                                    gpointer         page,
+                                    GtkNotebookPage *page,
                                     guint            page_num,
                                     gpointer         user_data)
 {
